# Generated by Django 5.2.6 on 2025-12-09 14:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_license', '0005_alter_license_options_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='license',
            name='support_status',
            field=models.CharField(default='unknown', max_length=20),
        ),
        migrations.AlterField(
            model_name='license',
            name='status',
            field=models.CharField(default='active', max_length=20),
        ),
    ]
